@@ -1,15 +1,16 @@
 """Provide the protocol for MySensors version 2.0."""
 
+from __future__ import annotations
+
 from collections.abc import Awaitable, Callable, Coroutine
 from enum import IntEnum
 from functools import wraps
-from typing import Any
+from typing import TYPE_CHECKING, Any
 
 from aiomysensors.exceptions import MissingChildError, MissingNodeError
-from aiomysensors.gateway import Gateway, MessageBuffer
+from aiomysensors.model.const import SYSTEM_CHILD_ID
 from aiomysensors.model.message import Message
 
-from . import SYSTEM_CHILD_ID
 from .protocol_15 import (  # noqa: F401
     INTERNAL_COMMAND_TYPE,
     STRICT_SYSTEM_COMMAND_TYPES,
@@ -24,24 +25,29 @@ from .protocol_15 import (
     OutgoingMessageHandler as OutgoingMessageHandler15,
 )
 
+if TYPE_CHECKING:
+    from aiomysensors.gateway import Gateway, MessageBuffer
+
+VERSION = "2.0"
+
 
 def handle_missing_node_child[
-    _IncomingMessageHandlerT: type[IncomingMessageHandler],
-    **_P,
+    IncomingMessageHandlerT: type[IncomingMessageHandler],
+    **P,
 ](
     func: Callable[
-        [_IncomingMessageHandlerT, Gateway, Message, MessageBuffer],
+        [IncomingMessageHandlerT, Gateway, Message, MessageBuffer],
         Awaitable[Message],
     ],
 ) -> Callable[
-    [_IncomingMessageHandlerT, Gateway, Message, MessageBuffer],
+    [IncomingMessageHandlerT, Gateway, Message, MessageBuffer],
     Coroutine[Any, Any, Message],
 ]:
     """Handle a missing node or child."""
 
     @wraps(func)
     async def wrapper(
-        self: _IncomingMessageHandlerT,
+        self: IncomingMessageHandlerT,
         gateway: Gateway,
         message: Message,
         message_buffer: MessageBuffer,
