@@ -1,7 +1,6 @@
 """Provide a serial transport."""
 
 import asyncio
-from typing import Tuple
 
 from serial_asyncio import open_serial_connection
 
@@ -19,9 +18,10 @@ class SerialTransport(StreamTransport):
 
     async def _open_connection(
         self,
-    ) -> Tuple[asyncio.StreamReader, asyncio.StreamWriter]:
+    ) -> tuple[asyncio.StreamReader, asyncio.StreamWriter]:
         """Open the stream connection."""
-        reader_writer_pair: Tuple[asyncio.StreamReader, asyncio.StreamWriter] = (
-            await open_serial_connection(url=self.port, baudrate=self.baud)
-        )
+        reader_writer_pair: tuple[
+            asyncio.StreamReader,
+            asyncio.StreamWriter,
+        ] = await open_serial_connection(url=self.port, baudrate=self.baud)
         return reader_writer_pair
